@@ -555,15 +555,6 @@ class FetchData(object):
         if not self.method:
             raise NoMethodError(url)
 
-        if self.method.supports_srcrev():
-            self.revisions = {}
-            for name in self.names:
-                self.revisions[name] = srcrev_internal_helper(self, d, name)
-
-            # add compatibility code for non name specified case
-            if len(self.names) == 1:
-                self.revision = self.revisions[self.names[0]]
-
         if hasattr(self.method, "urldata_init"):
             self.method.urldata_init(self, d)
 
@@ -579,6 +570,15 @@ class FetchData(object):
         self.donestamp = basepath + '.done'
         self.lockfile = basepath + '.lock'
 
+    def setup_revisons(self, d):
+        self.revisions = {}
+        for name in self.names:
+            self.revisions[name] = srcrev_internal_helper(self, d, name)
+
+        # add compatibility code for non name specified case
+        if len(self.names) == 1:
+            self.revision = self.revisions[self.names[0]]
+
     def setup_localpath(self, d):
         if not self.localpath:
             self.localpath = self.method.localpath(self.url, self, d)
